summaryrefslogtreecommitdiffstats
path: root/kinit/klauncher_main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kinit/klauncher_main.cpp')
-rw-r--r--kinit/klauncher_main.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/kinit/klauncher_main.cpp b/kinit/klauncher_main.cpp
index 80b96980c..632c82a8c 100644
--- a/kinit/klauncher_main.cpp
+++ b/kinit/klauncher_main.cpp
@@ -52,11 +52,11 @@ static KCmdLineOptions options[] =
extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
{
// Started via kdeinit.
if (fcntl(LAUNCHER_FD, F_GETFD) == -1)
{
fprintf(stderr, "%s", i18n("klauncher: This program is not supposed to be started manually.\n"
- "klauncher: It is started automatically by kdeinit.\n").local8Bit().data());
+ "klauncher: It is started automatically by tdeinit.\n").local8Bit().data());
return 1;
}
@@ -52,11 +52,11 @@ static KCmdLineOptions options[] =
extern "C" KDE_EXPORT int kdemain( int argc, char**argv )
{
- // Started via kdeinit.
+ // Started via tdeinit.
if (fcntl(LAUNCHER_FD, F_GETFD) == -1)
{